=======
Metrics
=======
.. currentmodule:: snapatac2

Quality Control
~~~~~~~~~~~~~~~

.. autosummary::
    :toctree: _autosummary

    metrics.frag_size_distr
    metrics.tsse
    metrics.frip
    metrics.summary_by_chrom